---
title: Automation module
summary: Provides the main interface to the OpenWebNet automation system.
---

The Automation module provides the main interface to the OpenWebNet automation system.
This allows controlling shutter, blinds, and other similar devices.

::: pyown.items.automation.WhatAutomation
    options:
        show_inheritance_diagram: true

::: pyown.items.automation.AutomationEvents
    options:
        show_inheritance_diagram: true

::: pyown.items.automation.Automation
    options:
        show_inheritance_diagram: true
    